aboutsummaryrefslogtreecommitdiff
path: root/src/controllers/PasswordReminderController.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/controllers/PasswordReminderController.php')
-rw-r--r--src/controllers/PasswordReminderController.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/controllers/PasswordReminderController.php b/src/controllers/PasswordReminderController.php
index ed3592e..569973b 100644
--- a/src/controllers/PasswordReminderController.php
+++ b/src/controllers/PasswordReminderController.php
@@ -23,13 +23,13 @@ class PasswordReminderController extends BaseController {
}
/**
* Set the userId and create a random token
* @param $userId
* @throws StoreResourceFailedException
* @return PasswordReminder
*/
- public function store($userId) {
- $user = User::findOrFail($userId);
+ public function store($userEmail) {
+ $user = User::findOrFail($userEmail);
$this->passwordReminder->userEmail = $user->email;
$this->passwordReminder->token = bin2hex(openssl_random_pseudo_bytes(24));
@@ -23,13 +23,13 @@ class PasswordReminderController extends BaseController {
}
/**
- * Set the userId and create a random token
- * @param $userId
+ * Set the userEmail and create a random token
+ * @param $userEmail
* @throws StoreResourceFailedException
* @return PasswordReminder